@@ -762,7 +762,7 @@ def ol_isinstance(var, typs):
 
     # NOTE: The current implementation of `isinstance` restricts the type of the
     # instance variable to types that are well known and in common use. The
-    # danger of unrestricted tyoe comparison is that a "default" of `False` is
+    # danger of unrestricted type comparison is that a "default" of `False` is
     # required and this means that if there is a bug in the logic of the
     # comparison tree `isinstance` returns False! It's therefore safer to just
     # reject the compilation as untypable!
@@ -770,7 +770,9 @@ def ol_isinstance(var, typs):
                         types.DictType, types.LiteralStrKeyDict, types.List,
                         types.ListType, types.Tuple, types.UniTuple, types.Set,
                         types.Function, types.ClassType, types.UnicodeType,
-                        types.ClassInstanceType, types.NoneType, types.Array)
+                        types.ClassInstanceType, types.NoneType, types.Array,
+                        types.Boolean, types.Float, types.UnicodeCharSeq,
+                        types.Complex)
     if not isinstance(var_ty, supported_var_ty):
         msg = f'isinstance() does not support variables of type "{var_ty}".'
         raise NumbaTypeError(msg)
@@ -1000,4 +1002,3 @@ def ol_str_generic(object=''):
         else:
             return repr(object)
     return impl
-
